/// <reference types="node" />
export interface IdentifierInstanceOptions {
    buffer?: Buffer;
    alphabet?: string;
    minLength?: number;
}
export declare const ProfanitySafeBase60 = "0123456789ABCDEFGHIJKLMNOPQRSTVWXYZabcdefghijklmnopqrstvwxyz";
export declare class Identifier {
    buffer: Buffer;
    alphabet: string;
    minLength: number;
    constructor(opts?: IdentifierInstanceOptions);
    fromBuffer(buffer: Buffer): this;
    trimBuffer(): this;
    toBuffer(): Buffer;
    fromHex(hex: string): this;
    toHex(minLength?: number): string;
    fromUniversallyUnique(uuid: string): this;
    toUniversallyUnique(): string;
    fromString(stringInput: string, alphabet?: string): this;
    toString(minLength?: number, alphabet?: string): string;
    toString(alphabet?: string, minLength?: number): string;
    fromInteger(numberInput: number): this;
    toInteger(): number;
    fromBigInt(bigInt: BigInt): this;
    toBigInt(): bigint;
    generateObject(): this;
    generateBigInt(includeMilliseconds?: boolean): this;
    generateRandomBigInt(): this;
    generateHexWithTimestamp(length: number, includeMilliseconds?: boolean): this;
    generateHex(length: number): this;
    generateUniversallyUnique(processNumber?: number): this;
    generateRandomString(desiredLength: number): this;
    getTimeAsHex(includeMilliseconds?: boolean): string;
    getRandomHexChar(allowZero?: boolean): string;
    getRandomHex(desiredLength: number): any;
    getRandomAlphabetChar(allowZero?: boolean): string;
}
export declare function getIdentifier(opts?: IdentifierInstanceOptions): Identifier;
export declare function getIdentifierFromInteger(integer: number): Identifier;
export declare function getIdentifierFromString(str: string): Identifier;
export declare function getIdentifierFromHex(hex: string): Identifier;
export declare function getIdentifierFromObject(hex: string): Identifier;
export declare function getIdentifierFromUniversallyUnique(uuid: string): Identifier;
export declare function generateObjectIdentifier(): Identifier;
export declare function generateUniversallyUniqueIdentifier(): Identifier;
export declare function generateIdentifierWithBigInt(): Identifier;
export declare function getHexIdentifierAsString(id: string): string;
export declare function getStringIdentifierAsHex(id: string): string;
export declare function getIntegerIdentifierAsString(integer: number): string;
export declare function getStringIdentifierAsInteger(str: string): number;
export declare function getIntegerIdentifierAsHex(integer: number): string;
export declare function getHexIdentifierAsInteger(hex: string): number;
export declare function getUniversallyUniqueIdentifierAsString(id: string): string;
export declare function getStringIdentifierAsUniversallyUnique(id: string): string;
